NAME = "vancouver_watching"

ICON = "🌈"

DESCRIPTION = f"{ICON} Vancouver Watching with AI."

VERSION = "3.380.1"

REPO_NAME = "vancouver-watching"

MARQUEE = "https://user-images.githubusercontent.com/1007567/196573547-b1c71b3b-7fac-4d2c-bba0-a87b063830da.png"
